=========
Changelog
=========


Unreleased
----------


v0.2.0
------
*03 June 2020*

Added
~~~~~
- Added ``--version`` / ``-v`` argument.

Fixed
~~~~~
- Exit gracefully on keyboard interrupt (``CTRL`` + ``C``) and termination
  signals.


v0.1.0
------
*30 May 2020*

- Initial release.
